@@ -181,8 +181,8 @@ preferences_get_value (const char *name)
 	char *key;
 	PreferencesEntry *entry;
 	
-	g_return_val_if_fail (name != NULL, 0);
-	g_return_val_if_fail (preferences_is_initialized (), 0);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (preferences_is_initialized (), NULL);
 
 	key = preferences_key_make (name);
 	result = eel_gconf_get_value (key);
@@ -444,8 +444,8 @@ eel_preferences_get (const char *name)
  	char *result;
 	GConfValue *value;
 
-	g_return_val_if_fail (name != NULL, 0);
-	g_return_val_if_fail (preferences_is_initialized (), 0);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (preferences_is_initialized (), NULL);
 
 	value = preferences_get_value (name);
 	result = preferences_gconf_value_get_string (value);
@@ -501,8 +501,8 @@ eel_preferences_get_string_list (const char *name)
 	PreferencesEntry *entry;
 	GConfValue *default_value;
 
-	g_return_val_if_fail (name != NULL, 0);
-	g_return_val_if_fail (preferences_is_initialized (), 0);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (preferences_is_initialized (), NULL);
 
 	value = preferences_get_value (name);
 	result = preferences_gconf_value_get_string_list (value);
@@ -931,7 +931,7 @@ preferences_entry_remove_auto_storage (PreferencesEntry *entry,
 				break;
 			case PREFERENCE_BOOLEAN:
 			case PREFERENCE_INTEGER:
-				update_auto_integer_or_boolean (storage, 0);
+				update_auto_integer_or_boolean (storage, NULL);
 				break;
 			default:
 				g_warning ("unexpected preference type %d in preferences_entry_remove_auto_storage", entry->type);
